==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkVolumeOutlineSource.java <==
// java wrapper for vtkVolumeOutlineSource object
//

package vtk;
import vtk.*;

public class vtkVolumeOutlineSource extends vtkPolyDataAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetVolumeMapper_2(vtkVolumeMapper id0);
  public void SetVolumeMapper(vtkVolumeMapper id0)
    { SetVolumeMapper_2(id0); }

  private native long GetVolumeMapper_3();
  public vtkVolumeMapper GetVolumeMapper() {
    long temp = GetVolumeMapper_3();

    if (temp == 0) return null;
    return (vtkVolumeMapper)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetGenerateScalars_4(int id0);
  public void SetGenerateScalars(int id0)
    { SetGenerateScalars_4(id0); }

  private native void GenerateScalarsOn_5();
  public void GenerateScalarsOn()
    { GenerateScalarsOn_5(); }

  private native void GenerateScalarsOff_6();
  public void GenerateScalarsOff()
    { GenerateScalarsOff_6(); }

  private native int GetGenerateScalars_7();
  public int GetGenerateScalars()
    { return GetGenerateScalars_7(); }

  private native void SetGenerateOutline_8(int id0);
  public void SetGenerateOutline(int id0)
    { SetGenerateOutline_8(id0); }

  private native void GenerateOutlineOn_9();
  public void GenerateOutlineOn()
    { GenerateOutlineOn_9(); }

  private native void GenerateOutlineOff_10();
  public void GenerateOutlineOff()
    { GenerateOutlineOff_10(); }

  private native int GetGenerateOutline_11();
  public int GetGenerateOutline()
    { return GetGenerateOutline_11(); }

  private native void SetGenerateFaces_12(int id0);
  public void SetGenerateFaces(int id0)
    { SetGenerateFaces_12(id0); }

  private native void GenerateFacesOn_13();
  public void GenerateFacesOn()
    { GenerateFacesOn_13(); }

  private native void GenerateFacesOff_14();
  public void GenerateFacesOff()
    { GenerateFacesOff_14(); }

  private native int GetGenerateFaces_15();
  public int GetGenerateFaces()
    { return GetGenerateFaces_15(); }

  private native void SetColor_16(double id0,double id1,double id2);
  public void SetColor(double id0,double id1,double id2)
    { SetColor_16(id0,id1,id2); }

  private native void SetColor_17(double id0[]);
  public void SetColor(double id0[])
    { SetColor_17(id0); }

  private native double[] GetColor_18();
  public double[] GetColor()
    { return GetColor_18(); }

  private native void SetActivePlaneId_19(int id0);
  public void SetActivePlaneId(int id0)
    { SetActivePlaneId_19(id0); }

  private native int GetActivePlaneId_20();
  public int GetActivePlaneId()
    { return GetActivePlaneId_20(); }

  private native void SetActivePlaneColor_21(double id0,double id1,double id2);
  public void SetActivePlaneColor(double id0,double id1,double id2)
    { SetActivePlaneColor_21(id0,id1,id2); }

  private native void SetActivePlaneColor_22(double id0[]);
  public void SetActivePlaneColor(double id0[])
    { SetActivePlaneColor_22(id0); }

  private native double[] GetActivePlaneColor_23();
  public double[] GetActivePlaneColor()
    { return GetActivePlaneColor_23(); }

  public vtkVolumeOutlineSource() { super(); }

  public vtkVolumeOutlineSource(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-19-aarch64.pkg.tar.xz: vtk/vtkVolumeOutlineSource.java <==
// java wrapper for vtkVolumeOutlineSource object
//

package vtk;
import vtk.*;

public class vtkVolumeOutlineSource extends vtkPolyDataAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetVolumeMapper_2(vtkVolumeMapper id0);
  public void SetVolumeMapper(vtkVolumeMapper id0)
    { SetVolumeMapper_2(id0); }

  private native long GetVolumeMapper_3();
  public vtkVolumeMapper GetVolumeMapper() {
    long temp = GetVolumeMapper_3();

    if (temp == 0) return null;
    return (vtkVolumeMapper)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetGenerateScalars_4(int id0);
  public void SetGenerateScalars(int id0)
    { SetGenerateScalars_4(id0); }

  private native void GenerateScalarsOn_5();
  public void GenerateScalarsOn()
    { GenerateScalarsOn_5(); }

  private native void GenerateScalarsOff_6();
  public void GenerateScalarsOff()
    { GenerateScalarsOff_6(); }

  private native int GetGenerateScalars_7();
  public int GetGenerateScalars()
    { return GetGenerateScalars_7(); }

  private native void SetGenerateOutline_8(int id0);
  public void SetGenerateOutline(int id0)
    { SetGenerateOutline_8(id0); }

  private native void GenerateOutlineOn_9();
  public void GenerateOutlineOn()
    { GenerateOutlineOn_9(); }

  private native void GenerateOutlineOff_10();
  public void GenerateOutlineOff()
    { GenerateOutlineOff_10(); }

  private native int GetGenerateOutline_11();
  public int GetGenerateOutline()
    { return GetGenerateOutline_11(); }

  private native void SetGenerateFaces_12(int id0);
  public void SetGenerateFaces(int id0)
    { SetGenerateFaces_12(id0); }

  private native void GenerateFacesOn_13();
  public void GenerateFacesOn()
    { GenerateFacesOn_13(); }

  private native void GenerateFacesOff_14();
  public void GenerateFacesOff()
    { GenerateFacesOff_14(); }

  private native int GetGenerateFaces_15();
  public int GetGenerateFaces()
    { return GetGenerateFaces_15(); }

  private native void SetColor_16(double id0,double id1,double id2);
  public void SetColor(double id0,double id1,double id2)
    { SetColor_16(id0,id1,id2); }

  private native void SetColor_17(double id0[]);
  public void SetColor(double id0[])
    { SetColor_17(id0); }

  private native double[] GetColor_18();
  public double[] GetColor()
    { return GetColor_18(); }

  private native void SetActivePlaneId_19(int id0);
  public void SetActivePlaneId(int id0)
    { SetActivePlaneId_19(id0); }

  private native int GetActivePlaneId_20();
  public int GetActivePlaneId()
    { return GetActivePlaneId_20(); }

  private native void SetActivePlaneColor_21(double id0,double id1,double id2);
  public void SetActivePlaneColor(double id0,double id1,double id2)
    { SetActivePlaneColor_21(id0,id1,id2); }

  private native void SetActivePlaneColor_22(double id0[]);
  public void SetActivePlaneColor(double id0[])
    { SetActivePlaneColor_22(id0); }

  private native double[] GetActivePlaneColor_23();
  public double[] GetActivePlaneColor()
    { return GetActivePlaneColor_23(); }

  public vtkVolumeOutlineSource() { super(); }

  public vtkVolumeOutlineSource(long id) { super(id); }
  public native long   VTKInit();

}
